@@ -1,10 +1,11 @@
 """ Helper functions for custom Splunk Search Commands
 """
 
+from typing import List
 
-def ensure_fields(results):
+
+def ensure_fields(results: List[dict]) -> List[dict]:
     """ Ensure that the first result has a placeholder key for *ALL* the fields """
-    # type: ignore (List[dict]) - > List[dict]
     # XXX: Make this smarter by only holding a fix number of results before moving on.
     # E.g. Assume no new fields after n rows with no new fields encountered
     field_set = set()
